==> descr_1.0.0.tar.gz: descr/man/CrossTable.Rd <==
\name{CrossTable}
\alias{CrossTable}
\title{Cross tabulation with tests for factor independence}
\description{
  An implementation of a cross-tabulation function with output
  similar to S-Plus crosstabs() and SAS Proc Freq (or SPSS format)
  with Chi-square, Fisher and McNemar tests of the independence
  of all table factors.
}
\usage{
CrossTable(x, y, digits = 3, max.width = NA, expected = FALSE,
           prop.r = TRUE, prop.c = TRUE, prop.t = TRUE,
           prop.chisq = TRUE, chisq = FALSE, fisher = FALSE,
           mcnemar = FALSE, resid = FALSE, sresid = FALSE,
           asresid = FALSE, missing.include = FALSE,
           format = c("SAS","SPSS"), dnn = NULL,
           cell.layout = TRUE, xlab, ylab, \dots)
}
\arguments{
  \item{x}{A vector or a matrix. If y is specified, x must be a vector.}
  \item{y}{A vector in a matrix or a dataframe.}
  \item{digits}{Number of digits after the decimal point for cell
    proportions.}
  \item{max.width}{In the case of a 1 x n table, the default will be
    to print the output horizontally. If the number of columns exceeds
    max.width, the table will be wrapped for each successive increment
    of max.width columns. If you want a single column vertical table,
    set max.width to 1.}
  \item{prop.r}{If \code{TRUE}, row proportions will be included.}
  \item{prop.c}{If \code{TRUE}, column proportions will be included.}
  \item{prop.t}{If \code{TRUE}, table proportions will be included.}
  \item{expected}{If \code{TRUE}, chisq will be set to \code{TRUE} and
    expected cell counts from the \eqn{\chi^2}{Chi-Square} will be included.
    The value of \code{expected} will be set to \code{TRUE} if \code{chisq},
    \code{resid}, \code{sresid}, \code{asresid} or \code{prop.chisq} is
    \code{TRUE}.}
  \item{prop.chisq}{If \code{TRUE}, chi-square contribution of each cell will be
    included.}
  \item{chisq}{If \code{TRUE}, the results of a chi-square test will be
    included. The value of \code{chisq} will be set to \code{TRUE} if
    \code{expected}, \code{resid}, \code{sresid} or \code{prop.chisq} is
    \code{TRUE}.}
  \item{fisher}{If \code{TRUE}, the results of a Fisher Exact test will
    be included.}
  \item{mcnemar}{If \code{TRUE}, the results of a McNemar test will
    be included.}
  \item{resid}{If \code{TRUE}, residual (Pearson) will be included. The value
    of \code{resid} will be set to \code{FALSE} if \code{format = "SAS"}.}
  \item{sresid}{If \code{TRUE},  standardized residual will be included. The
    value of \code{sresid} will be set to \code{FALSE} if \code{format =
      "SAS"}.}
  \item{asresid}{If \code{TRUE}, adjusted standardized residual will be
    included. The value of \code{asresid} will be set to \code{FALSE} if
    \code{format = "SAS"}.}
  \item{missing.include}{If \code{TRUE}, then remove any unused factor levels.}
  \item{format}{Either SAS (default) or SPSS, depending on the type of
    output desired.}
  \item{dnn}{the names to be given to the dimensions in the result (the dimnames
    names).}
  \item{cell.layout}{If \code{TRUE}, print the cell layout.}
  \item{xlab}{A title for the x axis when plotting the CrossTable object (see
    \code{\link[graphics]{title}}).}
  \item{ylab}{A title for the y axis when plotting the CrossTable object (see
    \code{\link[graphics]{title}}).}
  \item{\dots}{Optional arguments passed to \code{\link[stats]{chisq.test}}.}
}
\details{
  A summary table will be generated with cell row, column and table proportions
  and marginal totals and proportions. Expected cell counts can be printed if
  desired (if 'chisq = TRUE'). In the case of a 2 x 2 table, both corrected and
  uncorrected values will be included for appropriate tests. In the case of
  tabulating a single vector, cell counts and table proportions will be printed.

  Note 1: If 'x' is a vector and 'y' is not specified, no statistical tests will
  be performed, even if any are set to \code{TRUE}.

  Note 2: 'x' and 'y' labels will be truncated if the table is not going to
  fit to the screen, according to the value of \code{getOption("width")}.
}
\value{
  A list of class \code{CrossTable} containing parameters used by the
  \code{print.CrossTable} method and the following components:

  t:            An n by m matrix containing table cell counts.

  prop.row:     An n by m matrix containing cell row proportions.

  prop.col:     An n by m matrix containing cell column proportions.

  prop.tbl:     An n by m matrix containing cell table proportions.

  chisq:        Results from the Chi-Square test. A list with class
  'htest'. See \code{\link[stats]{chisq.test}} for details.

  chisq.corr:   Results from the corrected Chi-Square test. A list with
  class 'htest'. See \code{\link[stats]{chisq.test}} for details. ONLY
  included in the case of a 2 x 2 table.

  fisher.ts:    Results from the two-sided Fisher Exact test. A list
  with class 'htest'. See \code{\link[stats]{fisher.test}} for details. ONLY
  included if 'fisher' = TRUE.

  fisher.lt:    Results from the Fisher Exact test with HA = "less". A
  list with class 'htest'. See \code{\link[stats]{fisher.test}} for details.
  ONLY included if 'fisher' = TRUE and in the case of a
  2 x 2 table.

  fisher.gt:    Results from the Fisher Exact test with HA = "greater".
  A list with class 'htest'. See \code{\link[stats]{fisher.test}} for details.
  ONLY included if 'fisher' = TRUE and in the case of a
  2 x 2 table.

  mcnemar:      Results from the McNemar test. A list with class
  'htest'. See \code{\link[stats]{mcnemar.test}} for details. ONLY included
  if 'mcnemar' = TRUE.

  mcnemar.corr: Results from the corrected McNemar test. A list with
  class 'htest'. See \code{\link[stats]{mcnemar.test}} for details. ONLY
  included if 'mcnemar' = TRUE and in the case of a
  2 x 2 table.

  resid/sresid/asresid: Pearson Residuals (from chi-square tests).

}
\author{Jakson Aquino has splited the function \code{CrossTable} (from the
  package \code{gmodels}) in two: \code{CrossTable} and \code{print.CrossTable}.
  The \code{gmodels}'s function was developed by Marc Schwartz (original version
  posted to r-devel on Jul 27, 2002. SPSS format modifications added by Nitin Jain
  based upon code provided by Dirk Enzmann).}

\seealso{\code{\link{forODFTable}}, \code{\link[base]{table}},
  \code{\link[base]{prop.table}}, \code{\link[stats]{xtabs}},
  \code{\link{crosstab}}.}

\examples{
# Simple cross tabulation of education versus prior induced
# abortions using infertility data
data(warpbreaks, package = "datasets")
CrossTable(warpbreaks$wool, warpbreaks$tension,
           dnn = c("Wool", "Tension"))
}

==> descr_1.0.1.tar.gz: descr/man/CrossTable.Rd <==
\name{CrossTable}
\alias{CrossTable}
\title{Cross tabulation with tests for factor independence}
\description{
  An implementation of a cross-tabulation function with output
  similar to S-Plus crosstabs() and SAS Proc Freq (or SPSS format)
  with Chi-square, Fisher and McNemar tests of the independence
  of all table factors.
}
\usage{
CrossTable(x, y, digits = 3, max.width = NA, expected = FALSE,
           prop.r = TRUE, prop.c = TRUE, prop.t = TRUE,
           prop.chisq = TRUE, chisq = FALSE, fisher = FALSE,
           mcnemar = FALSE, resid = FALSE, sresid = FALSE,
           asresid = FALSE, missing.include = FALSE,
           format = c("SAS","SPSS"), dnn = NULL,
           cell.layout = TRUE, xlab, ylab, \dots)
}
\arguments{
  \item{x}{A vector or a matrix. If y is specified, x must be a vector.}
  \item{y}{A vector in a matrix or a dataframe.}
  \item{digits}{Number of digits after the decimal point for cell
    proportions.}
  \item{max.width}{In the case of a 1 x n table, the default will be
    to print the output horizontally. If the number of columns exceeds
    max.width, the table will be wrapped for each successive increment
    of max.width columns. If you want a single column vertical table,
    set max.width to 1.}
  \item{prop.r}{If \code{TRUE}, row proportions will be included.}
  \item{prop.c}{If \code{TRUE}, column proportions will be included.}
  \item{prop.t}{If \code{TRUE}, table proportions will be included.}
  \item{expected}{If \code{TRUE}, chisq will be set to \code{TRUE} and
    expected cell counts from the \eqn{\chi^2}{Chi-Square} will be included.
    The value of \code{expected} will be set to \code{TRUE} if \code{chisq},
    \code{resid}, \code{sresid}, \code{asresid} or \code{prop.chisq} is
    \code{TRUE}.}
  \item{prop.chisq}{If \code{TRUE}, chi-square contribution of each cell will be
    included.}
  \item{chisq}{If \code{TRUE}, the results of a chi-square test will be
    included. The value of \code{chisq} will be set to \code{TRUE} if
    \code{expected}, \code{resid}, \code{sresid} or \code{prop.chisq} is
    \code{TRUE}.}
  \item{fisher}{If \code{TRUE}, the results of a Fisher Exact test will
    be included.}
  \item{mcnemar}{If \code{TRUE}, the results of a McNemar test will
    be included.}
  \item{resid}{If \code{TRUE}, residual (Pearson) will be included. The value
    of \code{resid} will be set to \code{FALSE} if \code{format = "SAS"}.}
  \item{sresid}{If \code{TRUE},  standardized residual will be included. The
    value of \code{sresid} will be set to \code{FALSE} if \code{format =
      "SAS"}.}
  \item{asresid}{If \code{TRUE}, adjusted standardized residual will be
    included. The value of \code{asresid} will be set to \code{FALSE} if
    \code{format = "SAS"}.}
  \item{missing.include}{If \code{TRUE}, then remove any unused factor levels.}
  \item{format}{Either SAS (default) or SPSS, depending on the type of
    output desired.}
  \item{dnn}{the names to be given to the dimensions in the result (the dimnames
    names).}
  \item{cell.layout}{If \code{TRUE}, print the cell layout.}
  \item{xlab}{A title for the x axis when plotting the CrossTable object (see
    \code{\link[graphics]{title}}).}
  \item{ylab}{A title for the y axis when plotting the CrossTable object (see
    \code{\link[graphics]{title}}).}
  \item{\dots}{Optional arguments passed to \code{\link[stats]{chisq.test}}.}
}
\details{
  A summary table will be generated with cell row, column and table proportions
  and marginal totals and proportions. Expected cell counts can be printed if
  desired (if 'chisq = TRUE'). In the case of a 2 x 2 table, both corrected and
  uncorrected values will be included for appropriate tests. In the case of
  tabulating a single vector, cell counts and table proportions will be printed.

  Note 1: If 'x' is a vector and 'y' is not specified, no statistical tests will
  be performed, even if any are set to \code{TRUE}.

  Note 2: 'x' and 'y' labels will be truncated if the table is not going to
  fit to the screen, according to the value of \code{getOption("width")}.
}
\value{
  A list of class \code{CrossTable} containing parameters used by the
  \code{print.CrossTable} method and the following components:

  t:            An n by m matrix containing table cell counts.

  prop.row:     An n by m matrix containing cell row proportions.

  prop.col:     An n by m matrix containing cell column proportions.

  prop.tbl:     An n by m matrix containing cell table proportions.

  chisq:        Results from the Chi-Square test. A list with class
  'htest'. See \code{\link[stats]{chisq.test}} for details.

  chisq.corr:   Results from the corrected Chi-Square test. A list with
  class 'htest'. See \code{\link[stats]{chisq.test}} for details. ONLY
  included in the case of a 2 x 2 table.

  fisher.ts:    Results from the two-sided Fisher Exact test. A list
  with class 'htest'. See \code{\link[stats]{fisher.test}} for details. ONLY
  included if 'fisher' = TRUE.

  fisher.lt:    Results from the Fisher Exact test with HA = "less". A
  list with class 'htest'. See \code{\link[stats]{fisher.test}} for details.
  ONLY included if 'fisher' = TRUE and in the case of a
  2 x 2 table.

  fisher.gt:    Results from the Fisher Exact test with HA = "greater".
  A list with class 'htest'. See \code{\link[stats]{fisher.test}} for details.
  ONLY included if 'fisher' = TRUE and in the case of a
  2 x 2 table.

  mcnemar:      Results from the McNemar test. A list with class
  'htest'. See \code{\link[stats]{mcnemar.test}} for details. ONLY included
  if 'mcnemar' = TRUE.

  mcnemar.corr: Results from the corrected McNemar test. A list with
  class 'htest'. See \code{\link[stats]{mcnemar.test}} for details. ONLY
  included if 'mcnemar' = TRUE and in the case of a
  2 x 2 table.

  resid/sresid/asresid: Pearson Residuals (from chi-square tests).

}
\author{Jakson Aquino \email{jalvesaq@gmail.com} has splited the function
  \code{CrossTable} (from the package \code{gmodels}) in two:
  \code{CrossTable} and \code{print.CrossTable}. The \code{gmodels}'s function
  was developed by Marc Schwartz (original version posted to r-devel on Jul
  27, 2002. SPSS format modifications added by Nitin Jain based upon code
  provided by Dirk Enzmann).}

\seealso{\code{\link{forODFTable}}, \code{\link[base]{table}},
  \code{\link[base]{prop.table}}, \code{\link[stats]{xtabs}},
  \code{\link{crosstab}}.}

\examples{
# Simple cross tabulation of education versus prior induced
# abortions using infertility data
data(warpbreaks, package = "datasets")
CrossTable(warpbreaks$wool, warpbreaks$tension,
           dnn = c("Wool", "Tension"))
}
